biom.table.Table.is_empty — biom-format.org

# biom-format.org

## biom.table.Table.is_empty

« biom.table.Table.index :: Contents :: biom.table.Table.iter »

# biom.table.Table.is_empty

`Table.` `is_empty`()

  Check whether the table is empty

  Returns: | bool `True` if the table is empty, `False` otherwise

« biom.table.Table.index :: Contents :: biom.table.Table.iter »

© Copyright 2011-2013, The BIOM Format Development Team. Last updated on Nov 19, 2014. Created using Sphinx 1.2.3.